Learn R Programming

SDGdetector (version 2.7.3)

detect_region: Detect country or region names in text for further mapping

Description

Detect country or region names in text for further mapping.

Usage

detect_region(x, col)

Value

Returns the tool text outputs.

Arguments

x

Data frame or a string

col

Column name for text to be assessed

Examples

Run this code
x <- c("This paper explores the method and results from an independent
evidence based assessment of Australia's progress towards the SDGs",
"Last year alone, the United States experienced 14 separate billion-dollar
 disasters related to climate change")
col <- data.frame(x)
regions <- detect_region(x, col)

Run the code above in your browser using DataLab