powered by
Look around to match pattern in a sentence
lookaround_nearby_n(word_ls1, word_ls2, n, exclude = "", third_AND_string = "")
A regex string
is a string, which includes a list of words connected by "|" that indicates 'OR'
is a number, indicates the number of words to look around
is a vector, including a list of words to be excluded from match
similar to word_ls1 or word_ls2, it is a string that includes a list of words connected by "|" that indicates 'OR'
con1 <- c('apple', 'bean', 'food') con2 <- c('big', 'delicious') lookaround_nearby_n(word_ls1 = con1, word_ls2 = con2, n = 2, exclude = "", third_AND_string = "")
Run the code above in your browser using DataLab